@@ -3,13 +3,13 @@
 
 #if defined(HUNSPELL_STATIC)
 #  define LIBHUNSPELL_DLL_EXPORTED
-#elif defined(_MSC_VER)
+#elif defined(_WIN32)
 #  if defined(BUILDING_LIBHUNSPELL)
 #    define LIBHUNSPELL_DLL_EXPORTED __declspec(dllexport)
 #  else
 #    define LIBHUNSPELL_DLL_EXPORTED __declspec(dllimport)
 #  endif
-#elif defined(BUILDING_LIBHUNSPELL) && 1
+#elif defined(BUILDING_LIBHUNSPELL)
 #  define LIBHUNSPELL_DLL_EXPORTED __attribute__((__visibility__("hidden")))
 #else
 #  define LIBHUNSPELL_DLL_EXPORTED
